You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@activemq.apache.org by ch...@apache.org on 2010/07/07 06:14:56 UTC

svn commit: r961186 - /activemq/sandbox/activemq-apollo-actor/activemq-hawtdb/src/main/scala/org/apache/activemq/broker/store/hawtdb/HawtDBClient.scala

Author: chirino
Date: Wed Jul  7 04:14:56 2010
New Revision: 961186

URL: http://svn.apache.org/viewvc?rev=961186&view=rev
Log:
enable the periodic flush

Modified:
    activemq/sandbox/activemq-apollo-actor/activemq-hawtdb/src/main/scala/org/apache/activemq/broker/store/hawtdb/HawtDBClient.scala

Modified: activemq/sandbox/activemq-apollo-actor/activemq-hawtdb/src/main/scala/org/apache/activemq/broker/store/hawtdb/HawtDBClient.scala
URL: http://svn.apache.org/viewvc/activemq/sandbox/activemq-apollo-actor/activemq-hawtdb/src/main/scala/org/apache/activemq/broker/store/hawtdb/HawtDBClient.scala?rev=961186&r1=961185&r2=961186&view=diff
==============================================================================
--- activemq/sandbox/activemq-apollo-actor/activemq-hawtdb/src/main/scala/org/apache/activemq/broker/store/hawtdb/HawtDBClient.scala (original)
+++ activemq/sandbox/activemq-apollo-actor/activemq-hawtdb/src/main/scala/org/apache/activemq/broker/store/hawtdb/HawtDBClient.scala Wed Jul  7 04:14:56 2010
@@ -145,7 +145,7 @@ class HawtDBClient(hawtDBStore: HawtDBSt
     }
   }
 
-  val schedual_version = new AtomicInteger()
+  val schedule_version = new AtomicInteger()
 
   def start(onComplete:Runnable) = {
     lock {
@@ -215,14 +215,14 @@ class HawtDBClient(hawtDBStore: HawtDBSt
 
       recover(onComplete)
 
-      // Schedual periodic jobs.. they keep executing while schedual_version remains the same.
-      schedualCleanup(schedual_version.get())
-      // schedualFlush(schedual_version.get())
+      // Schedule periodic jobs.. they keep executing while schedule_version remains the same.
+      scheduleCleanup(schedule_version.get())
+      scheduleFlush(schedule_version.get())
     }
   }
 
   def stop() = {
-    schedual_version.incrementAndGet
+    schedule_version.incrementAndGet
     journal.close
     pageFileFactory.close
     lockFile.unlock
@@ -936,12 +936,12 @@ class HawtDBClient(hawtDBStore: HawtDBSt
   //
   /////////////////////////////////////////////////////////////////////
 
-  def schedualFlush(version:Int): Unit = {
+  def scheduleFlush(version:Int): Unit = {
     def try_flush() = {
-      if (version == schedual_version.get) {
+      if (version == schedule_version.get) {
         hawtDBStore.executor_pool {
           flush
-          schedualFlush(version)
+          scheduleFlush(version)
         }
       }
     }
@@ -957,14 +957,14 @@ class HawtDBClient(hawtDBStore: HawtDBSt
     }
   }
 
-  def schedualCleanup(version:Int): Unit = {
+  def scheduleCleanup(version:Int): Unit = {
     def try_cleanup() = {
-      if (version == schedual_version.get) {
+      if (version == schedule_version.get) {
         hawtDBStore.executor_pool {
           withTx {tx =>
             cleanup(tx)
           }
-          schedualCleanup(version)
+          scheduleCleanup(version)
         }
       }
     }